1.13
 * filters.pixelize - fixed pixels source
 * filters.pixelize - fixed memory leak
 * fixed MSVC9 compile errors

1.12

 * NEW - filters.pixelize
 * minor improvements

1.11

 * NEW - color.multiply
 * NEW - filters.noiseBlur
 * blur, hvBlur - optimization; fixed surface edge blur
 * optimization

1.10

 * color.alphaMask - method attribute (use mask.value or mask.alpha)
 * filters.gradient - RGBA gradients

1.9

 * NEW - filters.scratch
 * filters.shadow - fixed target/source surface format
 * deform module removed
 * new testing image - Lena
 * C code refactoring
 * documentation refactoring

1.8

 * New documentation

1.7

 * NEW - color.alphaMask 
 * NEW - color.hue 
 * NEW - color.lightness 
 * minor improvements

1.5

 * Improved setup/config script
 * Windows/MSVC support